:root {
  --bg0: #f6f7fb;
  --bg1: #eef2ff;
  --panel: rgba(255, 255, 255, 0.78);
  --panel2: rgba(255, 255, 255, 0.92);
  --line: rgba(17, 24, 39, 0.12);
  --text: rgba(17, 24, 39, 0.92);
  --muted: rgba(17, 24, 39, 0.68);
  --muted2: rgba(17, 24, 39, 0.52);
  --danger: #ff4d6d;
  --ok: #62f6d5;
  --brand: #0ea5e9;
  --brand2: #7c3aed;
  --shadow: 0 20px 60px rgba(17, 24, 39, 0.12);
  --radius: 18px;
  --radius-sm: 12px;
}

html,
body {
  height: 100%;
}

body {
  margin: 0;
  color: var(--text);
  background: radial-gradient(1200px 700px at 18% 18%, rgba(14, 165, 233, 0.14), transparent 58%),
    radial-gradient(900px 600px at 82% 14%, rgba(124, 58, 237, 0.12), transparent 60%),
    radial-gradient(1000px 700px at 55% 92%, rgba(34, 211, 238, 0.12), transparent 55%),
    linear-gradient(180deg, var(--bg0), var(--bg1));
  font-family: "Noto Sans SC", ui-sans-serif, system-ui, -apple-system, "Segoe UI", "Microsoft YaHei", "PingFang SC",
    sans-serif;
  letter-spacing: 0.2px;
}

body::before {
  content: "";
  position: fixed;
  inset: 0;
  pointer-events: none;
  background-image: repeating-linear-gradient(
    45deg,
    rgba(255, 255, 255, 0.04) 0px,
    rgba(255, 255, 255, 0.04) 1px,
    transparent 1px,
    transparent 10px
  );
  opacity: 0.15;
  mix-blend-mode: overlay;
}

* {
  box-sizing: border-box;
}

a {
  color: var(--brand);
  text-decoration: none;
}

a:hover {
  text-decoration: underline;
}

.appShell {
  display: grid;
  grid-template-columns: 320px 1fr;
  gap: 16px;
  height: 100vh;
  padding: 18px;
}

.sidebar {
  border: 1px solid var(--line);
  border-radius: var(--radius);
  background: linear-gradient(180deg, rgba(255, 255, 255, 0.82), rgba(255, 255, 255, 0.62));
  box-shadow: var(--shadow);
  overflow: hidden;
}

.sidebarHeader {
  padding: 18px 16px 12px 16px;
  border-bottom: 1px solid var(--line);
  background: radial-gradient(800px 220px at 20% 0%, rgba(14, 165, 233, 0.14), transparent 62%);
}

.brandTitle {
  font-family: "Noto Serif SC", ui-serif, Georgia, serif;
  font-size: 20px;
  letter-spacing: 0.6px;
}

.brandSub {
  margin-top: 6px;
  font-size: 12px;
  color: var(--muted);
  line-height: 1.35;
}

.stepList {
  padding: 10px;
}

.stepItem {
  display: flex;
  gap: 10px;
  align-items: flex-start;
  padding: 10px 10px;
  border-radius: 14px;
  cursor: pointer;
  user-select: none;
  border: 1px solid transparent;
}

.stepItem:not(.stepItemDisabled):hover {
  background: rgba(14, 165, 233, 0.06);
  border-color: rgba(14, 165, 233, 0.16);
}

.stepItemActive {
  background: rgba(14, 165, 233, 0.08);
  border-color: rgba(14, 165, 233, 0.2);
}

.stepItemActive:hover {
  background: rgba(14, 165, 233, 0.1);
  border-color: rgba(14, 165, 233, 0.26);
}

.stepItemDisabled {
  opacity: 0.45;
  cursor: not-allowed;
}

.stepItemDisabled:hover {
  background: transparent;
  border-color: transparent;
}

.stepDot {
  width: 26px;
  height: 26px;
  border-radius: 999px;
  display: grid;
  place-items: center;
  font-size: 12px;
  color: rgba(255, 255, 255, 0.96);
  background: linear-gradient(135deg, rgba(14, 165, 233, 1), rgba(124, 58, 237, 1));
  box-shadow: 0 10px 18px rgba(17, 24, 39, 0.14);
  flex: 0 0 auto;
}

.stepDotDone {
  background: linear-gradient(135deg, rgba(16, 185, 129, 1), rgba(14, 165, 233, 1));
}

.stepMeta {
  padding-top: 1px;
}

.stepTitle {
  font-size: 13px;
  font-weight: 650;
}

.stepDesc {
  margin-top: 2px;
  font-size: 12px;
  color: var(--muted);
  line-height: 1.35;
}

.main {
  border: 1px solid var(--line);
  border-radius: var(--radius);
  background: linear-gradient(180deg, rgba(255, 255, 255, 0.84), rgba(255, 255, 255, 0.62));
  box-shadow: var(--shadow);
  overflow: hidden;
  display: grid;
  grid-template-rows: auto 1fr auto;
}

.topbar {
  padding: 16px 18px;
  border-bottom: 1px solid var(--line);
  display: flex;
  align-items: center;
  justify-content: space-between;
  gap: 12px;
  background: radial-gradient(1000px 260px at 0% 0%, rgba(124, 58, 237, 0.09), transparent 66%);
}

.topbarTitle {
  font-size: 14px;
  font-weight: 700;
  letter-spacing: 0.35px;
}

.pill {
  display: inline-flex;
  align-items: center;
  gap: 8px;
  padding: 8px 10px;
  border-radius: 999px;
  border: 1px solid rgba(255, 255, 255, 0.14);
  background: rgba(255, 255, 255, 0.7);
  color: var(--muted);
  font-size: 12px;
}

.content {
  padding: 18px;
  overflow: auto;
}

.card {
  border: 1px solid rgba(17, 24, 39, 0.12);
  background: rgba(255, 255, 255, 0.72);
  border-radius: var(--radius);
  padding: 16px;
}

.card + .card {
  margin-top: 12px;
}

.cardTitle {
  font-size: 16px;
  font-weight: 800;
  letter-spacing: 0.2px;
  margin: 0 0 8px 0;
}

.cardHint {
  font-size: 12px;
  color: var(--muted);
  line-height: 1.5;
}

.grid2 {
  display: grid;
  grid-template-columns: 1fr 1fr;
  gap: 12px;
}

.grid3 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr;
  gap: 12px;
}

.field {
  display: grid;
  gap: 6px;
}

.labelRow {
  display: flex;
  align-items: baseline;
  justify-content: space-between;
  gap: 10px;
}

.label {
  font-size: 12px;
  color: var(--text);
  font-weight: 650;
}

.help {
  font-size: 11px;
  color: var(--muted2);
  line-height: 1.35;
}

input,
select,
textarea {
  width: 100%;
  border-radius: 12px;
  border: 1px solid rgba(17, 24, 39, 0.14);
  background: rgba(255, 255, 255, 0.9);
  color: var(--text);
  padding: 10px 10px;
  outline: none;
}

textarea {
  min-height: 90px;
  resize: vertical;
}

input:focus,
select:focus,
textarea:focus {
  border-color: rgba(14, 165, 233, 0.38);
  box-shadow: 0 0 0 4px rgba(14, 165, 233, 0.12);
}

.row {
  display: flex;
  gap: 10px;
  align-items: center;
  flex-wrap: wrap;
}

.btnRow {
  display: flex;
  gap: 10px;
  align-items: center;
  flex-wrap: wrap;
}

button {
  border: 0;
  cursor: pointer;
  border-radius: 14px;
  padding: 10px 12px;
  background: rgba(255, 255, 255, 0.82);
  color: rgba(17, 24, 39, 0.92);
  font-weight: 700;
  letter-spacing: 0.2px;
  border: 1px solid rgba(17, 24, 39, 0.12);
}

button:not(.btnPrimary):not(.btnDanger):hover {
  background: rgba(255, 255, 255, 0.92);
  border-color: rgba(17, 24, 39, 0.16);
}

button:disabled {
  opacity: 0.5;
  cursor: not-allowed;
}

.btnPrimary {
  background: linear-gradient(135deg, rgba(14, 165, 233, 0.95), rgba(124, 58, 237, 0.95));
  color: rgba(255, 255, 255, 0.96);
  border: 1px solid rgba(17, 24, 39, 0.08);
}

.btnPrimary:hover {
  background: linear-gradient(135deg, rgba(14, 165, 233, 0.95), rgba(124, 58, 237, 0.95));
  filter: brightness(1.05);
}

.btnDanger {
  background: rgba(255, 77, 109, 0.16);
  border-color: rgba(255, 77, 109, 0.28);
}

.btnDanger:hover {
  background: rgba(255, 77, 109, 0.18);
  border-color: rgba(255, 77, 109, 0.32);
}
.footer {
  border-top: 1px solid var(--line);
  padding: 14px 18px;
  display: flex;
  align-items: center;
  justify-content: space-between;
  gap: 12px;
}

.statusLine {
  font-size: 12px;
  color: var(--muted);
  line-height: 1.35;
}

.errorBox {
  margin-top: 10px;
  border: 1px solid rgba(255, 77, 109, 0.28);
  background: rgba(255, 77, 109, 0.1);
  color: rgba(17, 24, 39, 0.9);
  border-radius: 14px;
  padding: 12px;
  white-space: pre-wrap;
}

.okBox {
  margin-top: 10px;
  border: 1px solid rgba(98, 246, 213, 0.25);
  background: rgba(98, 246, 213, 0.08);
  border-radius: 14px;
  padding: 12px;
  color: rgba(17, 24, 39, 0.9);
}

.divider {
  height: 1px;
  background: var(--line);
  margin: 12px 0;
}

@media (max-width: 980px) {
  .appShell {
    grid-template-columns: 1fr;
    height: auto;
  }
}

